@@ -205,15 +205,13 @@ class Project:
         -   account_id
         -   region_name
         -   role_arn
-        -   repository_name
+        -   namespace
         -   services
 
         """
         result = {}
 
         for repo in self.config.get("image_repositories", []):
-            namespace = repo.get("namespace", self.namespace)
-
             # We should have uniqueness by the checks in prepare_config(), but
             # it doesn't hurt to check.
             assert repo["id"] not in result, repo["id"]
@@ -222,7 +220,7 @@ class Project:
                 "account_id": repo.get("account_id", self.account_id),
                 "region_name": repo.get("region_name", self.region_name),
                 "role_arn": repo.get("role_arn", self.role_arn),
-                "repository_name": f"{namespace}/{repo['id']}",
+                "namespace": repo.get("namespace", self.namespace),
                 "services": repo.get("services", []),
             }
 
@@ -252,8 +250,18 @@ class Project:
             role_arn=role_arn or self.role_arn
         )
 
+    def _ecs(self, *, cached=True, **kwargs):
+        if cached:
+            return self._ecs_cached(**kwargs)
+        return self._ecs_raw(**kwargs)
+
     @functools.lru_cache()
-    def _ecs(self, region_name=None, role_arn=None):
+    def _ecs_cached(self, **kwargs):
+        return self._ecs_raw(**kwargs)
+
+    # We can't use the __wrapped__ property of an lru_cached function
+    # when that function is a class method
+    def _ecs_raw(self, region_name=None, role_arn=None):
         return Ecs(
             region_name=region_name or self.region_name,
             role_arn=role_arn or self.role_arn
@@ -344,11 +352,12 @@ class Project:
 
         return dict(result)
 
-    def get_ecs_services(self, release, environment_id):
+    def get_ecs_services(self, release, environment_id, cached=True):
         def _get_service(service):
             ecs = self._ecs(
                 region_name=service.get('region_name'),
-                role_arn=service.get('role_arn')
+                role_arn=service.get('role_arn'),
+                cached=cached
             )
 
             ecs_service = ecs.find_matching_service(
@@ -369,8 +378,6 @@ class Project:
             except KeyError:
                 continue
 
-            available_services = []
-
             services = matched_image.get('services', [])
 
             available_services = [_get_service(service) for service in services]
@@ -387,7 +394,7 @@ class Project:
         on the tasks within those services. We check that the desiredCount
         of tasks matches the running count of tasks.
         """
-        ecs_services = self.get_ecs_services(release, environment_id)
+        ecs_services = self.get_ecs_services(release, environment_id, cached=False)
 
         is_deployed = True
 
@@ -404,12 +411,12 @@ class Project:
 
                 for task in tasks:
                     task_tags = parse_aws_tags(task["tags"])
+                    task_arn = task["taskArn"]
 
                     task_name = task_tags.get("deployment:service")
                     deployment_label = task_tags.get("deployment:label")
 
                     if deployment_label != service_deployment_label:
-                        task_arn = task["taskArn"]
                         print("")
                         print(f"Task in {task_name} has the wrong deployment label:")
                         print(f"Wanted:   {service_deployment_label}")
@@ -489,7 +496,7 @@ class Project:
         return result
 
     def _prepare_release(self, description, release_images):
-        previous_release = self.release_store.get_latest_release()
+        previous_release = self.release_store.get_most_recent_release()
 
         new_release = self._create_release(
             description=description,
@@ -549,6 +556,7 @@ class Project:
 
         try:
             matched_image = self.image_repositories[image_id]
+            namespace = matched_image["namespace"]
             ecr = self._ecr(
                 account_id=matched_image["account_id"],
                 region_name=matched_image["region_name"],
@@ -558,9 +566,10 @@ class Project:
             # TODO: Does it make sense to create an ECR client if we don't
             # have an ECR repo to tag in?
             ecr = self._ecr()
+            namespace = self.namespace
 
         return ecr.tag_image(
-            namespace=self.namespace,
+            namespace=namespace,
             image_id=image_id,
             tag=old_tag,
             new_tag=new_tag
